## Contributing

Visisipy aims to be a community-driven project and warmly accepts contributions. If you want to contribute, please email us (visisipy@mreye.nl) or [open a new discussion](https://github.com/MREYE-LUMC/visisipy/discussions).

## Code style

- Please format your docstrings according to [numpydoc](https://numpydoc.readthedocs.io/en/latest/format.html).
- Use `hatch` to lint, format and test the code.
